API docs for “spamfighter.core.storage.test.base.ExpirableStorageTestMixin”

# Class s.c.s.t.b.ExpirableStorageTestMixin:

Part of spamfighter.core.storage.test.base View Source View In Hierarchy

Known subclasses: spamfighter.core.storage.test.test_dbm.DBMStorageTestCase, spamfighter.core.storage.test.test_dbm.DomainedDBMStorageTestCase, spamfighter.core.storage.test.test_memory.DomainMemoryStorageTestCase, spamfighter.core.storage.test.test_memory.MemoryStorageTestCase

Тест на `spamfighter.interfaces.IExpirableStorage`.

Method | setUp | Undocumented
Method | tearDown | Undocumented
Method | testGetNotFound | Undocumented
Method | testGetOk | Undocumented
Method | testGetExpired | Undocumented
Method | testAdd | Undocumented
Method | testAppendNotFound | Undocumented
Method | testAppendTypeError1 | Undocumented
Method | testAppendTypeError2 | Undocumented
Method | testAppend | Undocumented
Method | testIncrNotFound | Undocumented
Method | testIncrTypeError1 | Undocumented
Method | testIncrTypeError2 | Undocumented
Method | testIncr | Undocumented
Method | testDeleteNotFound | Undocumented
Method | testDelete | Undocumented
Method | testSetUnlimited | Undocumented

def setUp(self): (source)
overridden in spamfighter.core.storage.test.test_dbm.DBMStorageTestCase, spamfighter.core.storage.test.test_dbm.DomainedDBMStorageTestCase, spamfighter.core.storage.test.test_memory.DomainMemoryStorageTestCase, spamfighter.core.storage.test.test_memory.MemoryStorageTestCase
Undocumented
def tearDown(self): (source)
overridden in spamfighter.core.storage.test.test_dbm.DBMStorageTestCase, spamfighter.core.storage.test.test_dbm.DomainedDBMStorageTestCase, spamfighter.core.storage.test.test_memory.MemoryStorageTestCase
Undocumented
def testGetNotFound(self): (source)
Undocumented
def testGetOk(self): (source)
Undocumented
def testGetExpired(self): (source)
overridden in spamfighter.core.storage.test.test_memory.MemoryStorageTestCase
Undocumented
def testAdd(self): (source)
Undocumented
def testAppendNotFound(self): (source)
Undocumented
def testAppendTypeError1(self): (source)
Undocumented
def testAppendTypeError2(self): (source)
Undocumented
def testAppend(self): (source)
Undocumented
def testIncrNotFound(self): (source)
Undocumented
def testIncrTypeError1(self): (source)
Undocumented
def testIncrTypeError2(self): (source)
Undocumented
def testIncr(self): (source)
Undocumented
def testDeleteNotFound(self): (source)
Undocumented
def testDelete(self): (source)
Undocumented
def testSetUnlimited(self): (source)
Undocumented